/*
** ZABBIX
** Copyright (C) 2000-2005 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/

#ifndef ZABBIX_DISCOVERER_H
#define ZABBIX_DISCOVERER_H

#include "common.h"

extern	int	CONFIG_DISCOVERER_FORKS;

void	update_host(DB_DHOST *dhost, const char *ip, int status, int now);
void	update_service(DB_DRULE *drule, DB_DCHECK *dcheck, DB_DHOST *dhost, char *ip, int port, int status, const char *value, int now);

void	main_discoverer_loop(zbx_process_t p, int num);

#endif
